@@ -3,8 +3,8 @@ package Ixchel::Actions::pkgs;
 use 5.006;
 use strict;
 use warnings;
-use File::Slurp;
 use Rex::Commands::Pkg;
+use base 'Ixchel::Actions::base';
 
 =head1 NAME
 
@@ -12,18 +12,26 @@ Ixchel::Actions::pkgs - Handles making sure desired packages are installed as sp
 
 =head1 VERSION
 
-Version 0.2.0
+Version 0.3.0
 
 =cut
 
-our $VERSION = '0.2.0';
+our $VERSION = '0.3.0';
 
-=head1 SYNOPSIS
+=head1 CLI SYNOPSIS
 
-    use Data::Dumper;
+ixchel -a pkgs
+
+=head1 CODE SYNOPSIS
 
     my $results=$ixchel->action(action=>'pkgs', opts=>{}'});
 
+    if ($results->{ok}) {
+        print $results->{filled_in};
+    }else{
+        die('Action errored... '.joined("\n", @{$results->{errors}}));
+    }
+
 =head1 DESCRIPTION
 
 The modules to be installed are determined by the config.
@@ -50,65 +58,11 @@ None.
 
 =cut
 
-sub new {
-	my ( $empty, %opts ) = @_;
+sub new_extra { }
 
-	my $self = {
-		config => {},
-		vars   => {},
-		arggv  => [],
-		opts   => {},
-	};
-	bless $self;
-
-	if ( defined( $opts{config} ) ) {
-		$self->{config} = $opts{config};
-	}
-
-	if ( defined( $opts{t} ) ) {
-		$self->{t} = $opts{t};
-	} else {
-		die('$opts{t} is undef');
-	}
-
-	if ( defined( $opts{share_dir} ) ) {
-		$self->{share_dir} = $opts{share_dir};
-	}
-
-	if ( defined( $opts{opts} ) ) {
-		$self->{opts} = \%{ $opts{opts} };
-	}
-
-	if ( defined( $opts{argv} ) ) {
-		$self->{argv} = $opts{argv};
-	}
-
-	if ( defined( $opts{vars} ) ) {
-		$self->{vars} = $opts{vars};
-	}
-
-	if ( defined( $opts{ixchel} ) ) {
-		$self->{ixchel} = $opts{ixchel};
-	}
-
-	$self->{results} = {
-		errors      => [],
-		status_text => '',
-		ok          => 0,
-	};
-
-	return $self;
-} ## end sub new
-
-sub action {
+sub action_Extra {
 	my $self = $_[0];
 
-	$self->{results} = {
-		errors      => [],
-		status_text => '',
-		ok          => 0,
-	};
-
 	my $latest = '';
 	my @latest_failed;
 	my @latest_handled;
@@ -166,16 +120,16 @@ sub action {
 
 	$self->status_add( status => 'Latest: ' . $latest );
 	$self->status_add( status => 'Latest Handled: ' . join( ', ', @latest_handled ) );
-	$self->status_add( error  => 1, status => 'Latest Failed: ' . join( ', ', @latest_failed ) );
+	$self->status_add( status => 'Latest Failed: ' . join( ', ', @latest_failed ) );
 	$self->status_add( status => 'Present: ' . join( ', ', @{ $self->{config}{pkgs}{present} } ) );
 	$self->status_add( status => 'Present Handled: ' . $present );
-	$self->status_add( error  => 1, status => 'Present Failed: ' . join( ', ', @present_failed ) );
+	$self->status_add( status => 'Present Failed: ' . join( ', ', @present_failed ) );
 	$self->status_add( status => 'Absent: ' . $absent );
 	$self->status_add( status => 'Absent Handled: ' . join( ', ', @absent_handled ) );
-	$self->status_add( error  => 1, status => 'Absent Failed: ' . join( ', ', @absent_failed ) );
+	$self->status_add( status => 'Absent Failed: ' . join( ', ', @absent_failed ) );
 
-	return $self->{results};
-} ## end sub action
+	return undef;
+} ## end sub action_Extra
 
 sub short {
 	return 'Install packages specified by the config.';
@@ -186,33 +140,4 @@ sub opts_data {
 ';
 }
 
-sub status_add {
-	my ( $self, %opts ) = @_;
-
-	if ( !defined( $opts{status} ) ) {
-		return;
-	}
-
-	if ( !defined( $opts{error} ) ) {
-		$opts{error} = 0;
-	}
-
-	if ( !defined( $opts{type} ) ) {
-		$opts{type} = 'pkgs';
-	}
-
-	my ( $sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst ) = localtime(time);
-	my $timestamp = sprintf( "%04d-%02d-%02dT%02d:%02d:%02d", $year + 1900, $mon + 1, $mday, $hour, $min, $sec );
-
-	my $status = '[' . $timestamp . '] [' . $opts{type} . ', ' . $opts{error} . '] ' . $opts{status};
-
-	print $status. "\n";
-
-	$self->{results}{status_text} = $self->{results}{status_text} . $status;
-
-	if ( $opts{error} ) {
-		push( @{ $self->{results}{errors} }, $opts{status} );
-	}
-} ## end sub status_add
-
 1;
